==> haskell-edisoncore-1.3.3.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 EdisonCore
version:              1.3.3.2
visibility:           public
id:                   EdisonCore-1.3.3.2-Wf1KO7wfJOFObClMgMqG7
key:                  EdisonCore-1.3.3.2-Wf1KO7wfJOFObClMgMqG7
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             https://github.com/robdockins/edison
synopsis:
    A library of efficient, purely-functional data structures (Core Implementations)

description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.

category:             Data Structures
abi:                  2079dfcfbd5d484331a1b28700a76ab3
exposed:              True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisoncore
hs-libraries:         HSEdisonCore-1.3.3.2-Wf1KO7wfJOFObClMgMqG7
depends:
    EdisonAPI-1.3.3.1-GmhlvZKM41qE6hBohhdpjs
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF array-0.5.4.0
    base-4.17.2.1 containers-0.6.7

haddock-interfaces:   /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html:         /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.3.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 EdisonCore
version:              1.3.3.2
visibility:           public
id:                   EdisonCore-1.3.3.2-ronXyhY05eL5tm7JLkk0y
key:                  EdisonCore-1.3.3.2-ronXyhY05eL5tm7JLkk0y
license:              MIT
maintainer:           robdockins AT fastmail DOT fm
author:               Chris Okasaki
stability:            Stable
homepage:             https://github.com/robdockins/edison
synopsis:
    A library of efficient, purely-functional data structures (Core Implementations)

description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.

category:             Data Structures
abi:                  029d21f582bf2f1cdd2570063f8fc739
exposed:              True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/EdisonCore-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edisoncore
hs-libraries:         HSEdisonCore-1.3.3.2-ronXyhY05eL5tm7JLkk0y
depends:
    EdisonAPI-1.3.3.2-2mD4dBWxvUBHilR6ZGP27D
    QuickCheck-2.14.3-BltPJloV4Un5EUIM4U1iqr array-0.5.4.0
    base-4.17.2.1 containers-0.6.7

haddock-interfaces:   /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html:         /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
